@@ -1,4 +1,4 @@
-// $Id: Global.cc 2871 2007-12-09 14:33:44Z flaterco $
+// $Id: Global.cc 2946 2008-01-18 23:12:25Z flaterco $
 
 /*  Global  Global variables and functions.
 
@@ -470,13 +470,13 @@ the selected mode.  The currently supported combinations of mode and format\n\
 are as folows:\n\
 \n\
 	 MODE\n\
-      abcCglmprs\n\
-  F c   X   XXX\n\
-  O h X XX X\n\
+      abcCgklmprs\n\
+  F c   X    XXX\n\
+  O h X XX  X\n\
   R i   X\n\
   M l   XX\n\
-  A p     X\n\
-  T t XXXXXXXXXX";
+  A p     XX\n\
+  T t XXXXXXXXXXX";
     break;
   case Error::BAD_EVENTMASK:
     text_out += "BAD_EVENTMASK\n\
