@@ -1,4 +1,4 @@
-// $Id: Station.cc 2833 2007-12-01 01:27:02Z flaterco $
+// $Id: Station.cc 2946 2008-01-18 23:12:25Z flaterco $
 
 /*  Station  A tide station.
 
@@ -1006,6 +1006,15 @@ void Station::graphMode (Dstr &text_out,
 }
 
 
+void Station::clockMode (Dstr &text_out) {
+  TTYGraph g (Global::settings["tw"].u,
+	      Global::settings["th"].u,
+	      Graph::clock);
+  g.drawTides (this, (time_t)time(NULL));
+  g.print (text_out);
+}
+
+
 void Station::graphModePNG (FILE *fp, Timestamp startTime) {
   RGBGraph g (Global::settings["gw"].u, Global::settings["gh"].u);
   g.drawTides (this, startTime);
@@ -1014,6 +1023,16 @@ void Station::graphModePNG (FILE *fp, Timestamp startTime) {
 }
 
 
+void Station::clockModePNG (FILE *fp) {
+  RGBGraph g (Global::settings["cw"].u,
+	      Global::settings["gh"].u,
+	      Graph::clock);
+  g.drawTides (this, (time_t)time(NULL));
+  Global::PNGFile = fp;
+  g.writeAsPNG (Global::writePNGToFile);
+}
+
+
 void Station::print (Dstr &text_out,
                      Timestamp startTime,
                      Timestamp endTime,
@@ -1091,6 +1110,19 @@ void Station::print (Dstr &text_out,
     }
     break;
 
+  case Mode::clock:
+    switch (form) {
+    case Format::PNG:
+      Global::log ("Can't happen:  Station::print called for clock mode, PNG form:  use graphModePNG instead\n", LOG_ERR);
+      assert (false);
+    case Format::text:
+      clockMode (text_out);
+      break;
+    default:
+      Global::formatBarf (mode, form);
+    }
+    break;
+
   default:
     {
       Dstr details ("Unsupported mode: ");
