@@ -1,4 +1,4 @@
-// $Id: xxX.cc 2641 2007-09-02 21:31:02Z flaterco $
+// $Id: xxX.cc 2935 2008-01-10 02:15:21Z flaterco $
 
 /*  xxX  Globals for interfacing with X11.
 
@@ -436,6 +436,17 @@ const Widget xxX::connect (int &argc, char **argv) {
   assert (onlyonce);
   onlyonce = false;
 
+  // 2008-01  Workaround for an extreme example of code rot (breakage
+  // inflicted by backward-incompatible changes occurring in the
+  // environment).  The Composite extension throws ARGB visuals at
+  // unsuspecting legacy applications.  ARGB visuals are reported as
+  // TrueColor visuals, which is a lie.  They aren't substitutable.  The
+  // alpha channel defaults to transparent, so an application that doesn't
+  // know it's there will NOT work correctly.  There isn't even a proper way
+  // to determine if an ARGB visual is what you got!
+  static char env_string[] = "XLIB_SKIP_ARGB_VISUALS=1";
+  require (putenv (env_string) == 0);
+
   Widget widget;
 
   // See if we can get a nice true color visual (code fragment 11-5, X
